
/*
 Fichier permettant de creer une geometrie 3D de coupleur
          magnetique coaxial quelconque.
      Julien Fontchastagner, UL-GREEN, mars 2019.
*/

// Donnes geometriques d'entree et dialogue avec GetDP
Include "data.geo";

// On cree la geometrie a l'ancienne
SetFactory("Built-in");
Geometry.ExtrudeReturnLateralEntities = 1;


// Points
Point(1) = {0,0,0};
Point(2) = {R0,0,0};
Point(3) = {R1,0,0};
Point(4) = {R2,0,0};
Point(5) = {R3,0,0};
Point(6) = {R4,0,0};
Point(7) = {R5,0,0};
Point(8) = {Ri,0,0};
Point(9) = {Re,0,0};

// Lignes
Line(1) = {2,3};
Line(2) = {3,4};
Line(3) = {4,5};
Line(4) = {5,6};
Line(5) = {6,7};
Line(6) = {8,2};
Line(7) = {7,9};
Transfinite Line{1,2,3,4,5,6,7} = ndiv+1 Using Progression 1.0;
ldroite[] = {1,2,3,4,5,6,7};

// Differents cas geometriques possibles selon 
//   les largeurs angulaires des aimants
If ( alpha2 < (1.0-alpha1) )
  cas = 2;
EndIf
If ( alpha2 > (1.0-alpha1) )
  cas = 3;
EndIf
If (Fabs(1.0-alpha1-alpha2) <= 1e-2*alpha2) // egalite ou presque
  cas = 1;
  alpha2 = 1.0-alpha1;
EndIf

// Construction des Faces du motif elementaire 
// par extrusions rotatives...
scul1[] = {};
saim1[] = {};
sair1[] = {};
sentrf[] = {};
saim2n[] = {};
saim2s[] = {};
sair2[] = {};
scul2[] = {};
// ... puis des volumes correspondants 
// par extrusions translatives
sdom[] = {};
vdom[] = {};
ventrf[] = {};
sdir[] = {};
sgauche[] = {};
sdroite[] = {};

// 1er cas : alpha1+alpha2 = 1
If (cas == 1)
  // Surfaces
  l_to_extrude[] = ldroite[];
  nlayers = R3*alpha2/2*Pi/pp/lmailg;
  If (nlayers < 2.0)
    nlayers = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, alpha2/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2n[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  nlayers2 = R3*alpha1*Pi/pp/lmailg;
  If (nlayers2 < 2.0)
    nlayers2 = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, alpha1*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers2}; Recombine; };
  scul1[] += {outs[1]};
  saim1[] += {outs[5]};
  sentrf[] += {outs[9]};
  sair2[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  outs[] = Extrude { {0,0,1}, {0,0,0}, alpha2/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2s[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  sdir[] += {scul1[],sair1[],saim1[],sentrf[],saim2n[],saim2s[],sair2[],scul2[],sdom[]};
  
  // Volumes
  nlayersl = 1+L/2.0/lmailg/2.0;
  outv[] = Extrude {0,0,L/2.0} {Surface{sdom[]}; Layers{nlayersl}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25],outv[31]}; 
  sdir[] += {outv[5],outv[9],outv[17],outv[21],outv[29],outv[33]};
  sdroite[] += {outv[2],outv[8]};
  sgauche[] += {outv[28],outv[34]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24],outv[30]}; 
  nlayersl2 = 1+L/2.0/lmailg/4.0;
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25],outv[31]}; 
  sdroite[] += {outv[2],outv[8]};
  sgauche[] += {outv[28],outv[34]};
  sdir[] += {outv[5],outv[9],outv[17],outv[21],outv[29],outv[33]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24],outv[30]};
  outv[] = Extrude {0,0,L/2.0} {Surface{scul1[]}; Layers{nlayersl}; Recombine; } ;
  vcul1[] = {outv[1],outv[7],outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  s_to_extrude[] = {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  sdir[] += {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/2.0} {Surface{sair1[],saim1[]}; Layers{nlayersl}; Recombine; } ;
  vair1[] = {outv[1],outv[7]};
  vaim1[] = {outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[10]};
  s_to_extrude[] = {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[10]};
  sdir[] += {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/2.0} {Surface{sentrf[]}; Layers{nlayersl}; Recombine; } ;
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  ventrf[] += {outv[1],outv[7],outv[13]};
  s_to_extrude[] = {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  ventrf[] += {outv[1],outv[7],outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  sdir[] += {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/2.0} {Surface{saim2n[],sair2[],saim2s[]}; Layers{nlayersl}; Recombine; } ;
  vaim2n[] = {outv[1]};
  vaim2s[] = {outv[13]};
  vair2[] = {outv[7]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  s_to_extrude[] = {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  sdir[] += {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/2.0} {Surface{scul2[]}; Layers{nlayersl}; Recombine; } ;
  vcul2[] = {outv[1],outv[7],outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  s_to_extrude[] = {outv[0],outv[6],outv[12]};
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[16]};
  sdir[] += {outv[0],outv[6],outv[12]};  
EndIf

// 2eme cas : alpha1+alpha2 < 1
If (cas == 2)
  // Surfaces
  l_to_extrude[] = ldroite[];
  nlayers = R3*alpha2/2*Pi/pp/lmailg;
  If (nlayers < 2.0)
    nlayers = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, alpha2/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2n[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  nlayers2 = R3*(1.0-alpha1-alpha2)/2*Pi/pp/lmailg;
  If (nlayers2 < 2.0)
    nlayers2 = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, (1.0-alpha1-alpha2)/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers2}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  sair2[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  nlayers3 = R3*alpha1*Pi/pp/lmailg;
  If (nlayers3 < 2.0)
    nlayers3 = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, alpha1*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers3}; Recombine; };
  scul1[] += {outs[1]};
  saim1[] += {outs[5]};
  sentrf[] += {outs[9]};
  sair2[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  outs[] = Extrude { {0,0,1}, {0,0,0}, (1.0-alpha1-alpha2)/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers2}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  sair2[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  outs[] = Extrude { {0,0,1}, {0,0,0}, alpha2/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2s[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  sdir[] += {scul1[],sair1[],saim1[],sentrf[],saim2n[],saim2s[],sair2[],scul2[],sdom[]};

  // Volumes
  nlayersl = 1+L/2.0/lmailg/2.0;
  outv[] = Extrude {0,0,L/2.0} {Surface{sdom[]}; Layers{nlayersl}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25],
    outv[31],outv[37],outv[43],outv[49],outv[55]}; 
  sdir[] += {outv[5],outv[9],outv[17],outv[21],outv[29],
    outv[33],outv[41],outv[45],outv[53],outv[57]};
  sdroite[] += {outv[2],outv[8]};
  sgauche[] += {outv[52],outv[58]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24],
    outv[30],outv[36],outv[42],outv[48],outv[54]}; 
  nlayersl2 = 1+L/2.0/lmailg/4.0;
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25],
    outv[31],outv[37],outv[43],outv[49],outv[55]}; 
  sdir[] += {outv[5],outv[9],outv[17],outv[21],outv[29],
    outv[33],outv[41],outv[45],outv[53],outv[57]};
  sdroite[] += {outv[2],outv[8]};
  sgauche[] += {outv[52],outv[58]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24],
    outv[30],outv[36],outv[42],outv[48],outv[54]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{scul1[]}; Layers{nlayersl}; Recombine; } ;
  vcul1[] = {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{sair1[],saim1[]}; Layers{nlayersl}; Recombine; } ;
  vair1[] = {outv[1],outv[7],outv[13],outv[19]};
  vaim1[] = {outv[25]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[22]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[22]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{sentrf[]}; Layers{nlayersl}; Recombine; } ;
  ventrf[] = {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  ventrf[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{saim2n[],saim2s[],sair2[]}; Layers{nlayersl}; Recombine; } ;
  vaim2n[] = {outv[1]};
  vaim2s[] = {outv[7]};
  vair2[] = {outv[13],outv[19],outv[25]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[10]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[10]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{scul2[]}; Layers{nlayersl}; Recombine; } ;
  vcul2[] = {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
EndIf

// 3eme cas : alpha1+alpha2 > 1
If (cas == 3)
  // Surfaces
  l_to_extrude[] = ldroite[];
  nlayers = R3*(1.0-alpha1)/2*Pi/pp/lmailg;
  If (nlayers < 2.0)
    nlayers = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, (1.0-alpha1)/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2n[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  nlayers2 = R3*(alpha1+alpha2-1.0)/2*Pi/pp/lmailg;
  If (nlayers2 < 2.0)
    nlayers2 = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, (alpha1+alpha2-1.0)/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers2}; Recombine; };
  scul1[] += {outs[1]};
  saim1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2n[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  nlayers3 = R3*(1.0-alpha2)*Pi/pp/lmailg;
  If (nlayers3 < 2.0)
    nlayers3 = 2;
  EndIf
  outs[] = Extrude { {0,0,1}, {0,0,0}, (1.0-alpha2)*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers3}; Recombine; };
  scul1[] += {outs[1]};
  saim1[] += {outs[5]};
  sentrf[] += {outs[9]};
  sair2[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  outs[] = Extrude { {0,0,1}, {0,0,0}, (alpha1+alpha2-1.0)/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers2}; Recombine; };
  scul1[] += {outs[1]};
  saim1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2s[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  l_to_extrude[] = {outs[0],outs[4],outs[8],outs[12],outs[16],outs[20],outs[24]};
  outs[] = Extrude { {0,0,1}, {0,0,0}, (1.0-alpha1)/2*Pi/pp} 
                   { Line {l_to_extrude[]}; Layers{nlayers}; Recombine; };
  scul1[] += {outs[1]};
  sair1[] += {outs[5]};
  sentrf[] += {outs[9]};
  saim2s[] += {outs[13]};
  scul2[] += {outs[17]};
  sdom[] += {outs[21],outs[25]};
  sdir[] += {scul1[],sair1[],saim1[],sentrf[],saim2n[],saim2s[],sair2[],scul2[],sdom[]};

  // Volumes
  nlayersl = 1+L/2.0/lmailg/2.0;
  outv[] = Extrude {0,0,L/2.0} {Surface{sdom[]}; Layers{nlayersl}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25],
    outv[31],outv[37],outv[43],outv[49],outv[55]}; 
  sdir[] += {outv[5],outv[9],outv[17],outv[21],outv[29],
    outv[33],outv[41],outv[45],outv[53],outv[57]};
  sdroite[] += {outv[2],outv[8]};
  sgauche[] += {outv[52],outv[58]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24],
    outv[30],outv[36],outv[42],outv[48],outv[54]}; 
  nlayersl2 = 1+L/2.0/lmailg/4.0;
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25],
    outv[31],outv[37],outv[43],outv[49],outv[55]}; 
  sdir[] += {outv[5],outv[9],outv[17],outv[21],outv[29],
    outv[33],outv[41],outv[45],outv[53],outv[57]};
  sdroite[] += {outv[2],outv[8]};
  sgauche[] += {outv[52],outv[58]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24],
    outv[30],outv[36],outv[42],outv[48],outv[54]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{scul1[]}; Layers{nlayersl}; Recombine; } ;
  vcul1[] = {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{sair1[],saim1[]}; Layers{nlayersl}; Recombine; } ;
  vair1[] = {outv[1],outv[7]};
  vaim1[] = {outv[13],outv[19],outv[25]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[10]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[10]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{sentrf[]}; Layers{nlayersl}; Recombine; } ;
  ventrf[] = {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  ventrf[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
   outv[] = Extrude {0,0,L/2.0} {Surface{saim2n[],saim2s[],sair2[]}; Layers{nlayersl}; Recombine; } ;
  vaim2n[] = {outv[1],outv[7]};
  vaim2s[] = {outv[13],outv[19]};
  vair2[] = {outv[25]};
  sdroite[] += {outv[2]};
  sgauche[] += {outv[22]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[22]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/2.0} {Surface{scul2[]}; Layers{nlayersl}; Recombine; } ;
  vcul2[] = {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  s_to_extrude[] = {outv[0],outv[6],outv[12],outv[18],outv[24]}; 
  outv[] = Extrude {0,0,L/4.0} {Surface{s_to_extrude[]}; Layers{nlayersl2}; Recombine; } ;
  vdom[] += {outv[1],outv[7],outv[13],outv[19],outv[25]}; 
  sdroite[] += {outv[2]};
  sgauche[] += {outv[28]};
  sdir[] += {outv[0],outv[6],outv[12],outv[18],outv[24]};   
EndIf

// Regions physiques pour GetDP
// Faces
Physical Surface(DIRICHLET) = {sdir[]};
Physical Surface(DROITE) = {sdroite[]};
Physical Surface(GAUCHE) = {sgauche[]};
// Volumes
Physical Volume(AIR) = {vdom[],vair1[],vair2[]};
Physical Volume(CUL1) = {vcul1[]};
Physical Volume(CUL2) = {vcul2[]};
Physical Volume(AIM1) = {vaim1[]};
Physical Volume(ENTRF) = {ventrf[]};
Physical Volume(AIM2N) = {vaim2n[]};
Physical Volume(AIM2S) = {vaim2s[]};


//// Un peu de cosmetisme pour finir...
Color Gray {Volume{vcul1[],vcul2[]};}
Color White {Volume{ventrf[],vdom[],vair1[],vair2[]};}
Color Red {Volume{vaim1[]};}
Color Blue {Volume{vaim2n[],vaim2s[]};}


